Paradigm.Graph.GitRepoGraph (paradigm v0.3.0)

A graph implementation that adapts git repos to graph nodes. Uses the GitRepo canonical model to represent repositories, commits, branches, and tags as nodes.

Summary

Functions

new(opts \\ [])

new(root_path, opts)